/**
 * JASMINe
 * Copyright (C) 2009-2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JasmineEventToJasmineEventEB.java 7645 2011-02-01 15:40:31Z jlegrand $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eventswitch.transformers;

import java.util.ArrayList;
import java.util.List;

import org.mule.transformers.AbstractTransformer;
import org.mule.umo.transformer.TransformerException;
import org.ow2.jasmine.event.beans.JasmineEventEB;
import org.ow2.jasmine.event.messages.JasmineEvent;
import org.ow2.jasmine.event.messages.JasmineEventDetails;

/**
 * Transforms a JasmineEvent into a list of JasmineEventEB.
 *
 * @author jlegrand
 */
public class JasmineEventToJasmineEventEB extends AbstractTransformer {

    /**
     * Registers the transformer on Mule.
     *
     * @see org.mule.transformers.AbstractTransformer
     */
    public JasmineEventToJasmineEventEB() {
        super();
        this.registerSourceType(JasmineEvent.class);
        this.setReturnClass(List.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected List<JasmineEventEB> doTransform(final Object src, final String encoding) throws TransformerException {

        JasmineEvent je = (JasmineEvent) src;
        List<JasmineEventDetails> details = je.getEvents();
        List<JasmineEventEB> result = new ArrayList<JasmineEventEB>();

        for (JasmineEventDetails detail : details) {
            result.add(new JasmineEventEB(je.getDomain(), je.getServer(), detail.getSource(), detail.getProbe(), detail
                .getValue(), detail.getTimestamp(), detail.getSname()));
        }

        return result;
    }

}
